@@ -2,10 +2,15 @@ $(document).ready( function() {
   var send = false;
   $("#update").click(function(){
     var haspwd = false;
+    var hasAccount = !($("input#hasAccount").val() === "");
     if($("input#username").val() === "" || !$("input#username").val().match(/^[\w\d\._-]+$/)){
   		$("#error").Popup("Invalid user name. Please check it!", {type:'alert', duration:3000});
 			return false;
 		}
+    else if ($("input#username").val().length <6){
+      $("#error").Popup("Username must have at least 6 characters", {type:'alert', duration:3000});
+      return false;
+    }
 		if($("input#name").val() === ""){
 			$("#error").Popup("Please enter your name and surname!", {type:'alert', duration:3000});
   		return false;
@@ -14,6 +19,14 @@ $(document).ready( function() {
 			$("#error").Popup("Please enter a valid email adress!", {type:'alert', duration:3000});
 			return false;
 		}
+    if(!hasAccount && !$("input#password").val().match(/^[\w\d\._-]+$/)){
+      $("#error").Popup("Please enter your new password!", {type:'alert', duration:3000});
+      return false;
+    }
+    if ($("input#password").val() !== "" && $("input#password").val().length <6){
+      $("#error").Popup("The password must have at least 6 characters", {type:'alert', duration:3000});
+      return false;
+    }
     if($("input#password").val() !== ""){
       if($("input#password").val() === "" || !$("input#password").val().match(/^[\w\d\._-]+$/)){
       	$("#error").Popup("Please enter your new password!", {type:'alert', duration:3000});
@@ -25,16 +38,20 @@ $(document).ready( function() {
       }
       haspwd = true;
     }
+    if(!$("input#rcode").val().match(/^[\w\d]+$/)){
+    	$("#error").Popup("Please enter your password recovery code.", {type:'alert', duration:3000});
+			return false;
+		}
     if(send) return false;
     send = true;
     $.ajax({
   		type: "POST",
-			url: $SCRIPT_ROOT + '/updateAccount',
+			url: $SCRIPT_ROOT + ((hasAccount)? '/updateAccount':'/configAccount'),
 			data: {name: $("input#name").val(), username:$("input#username").val(), email:$("input#email").val(),
-				password:((haspwd) ? $("input#password").val():"")},
+				password:((haspwd) ? $("input#password").val():""), rcode:$("input#rcode").val()},
 			success: function(data){
         if(data.code ==1){
-          $("#error").Popup("Your account informations has been saved!", {type:'confirm', duration:3000});
+          location.href = $SCRIPT_ROOT+"/"
         }
         else{
           $("#error").Popup(data.result, {type:'error', duration:5000});
